summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirtreeiterators.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdirstat/kdirtreeiterators.h')
-rw-r--r--kdirstat/kdirtreeiterators.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/kdirstat/kdirtreeiterators.h b/kdirstat/kdirtreeiterators.h
index 2ab3382..f7a3ae8 100644
--- a/kdirstat/kdirtreeiterators.h
+++ b/kdirstat/kdirtreeiterators.h
@@ -27,9 +27,9 @@ namespace KDirStat
**/
typedef enum
{
- KDotEntryTransparent, // Flatten hierarchy - move dot entry tqchildren up
+ KDotEntryTransparent, // Flatten hierarchy - move dot entry children up
KDotEntryAsSubDir, // Treat dot entry as ordinary subdirectory
- KDotEntryIgnore // Ignore dot entry and its tqchildren completely
+ KDotEntryIgnore // Ignore dot entry and its children completely
} KDotEntryPolicy;
@@ -47,8 +47,8 @@ namespace KDirStat
/**
* Iterator class for tqchildren of a @ref KFileInfo object. For optimum
* performance, this iterator class does NOT return tqchildren in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
*
@@ -66,37 +66,37 @@ namespace KDirStat
* subdirectory child and each (direct) file child of 'node'.
* Notice: This does not recurse into subdirectories!
*
* @short (unsorted) iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoIterator
{
public:
/**
* Constructor: Initialize an iterator object to iterate over the
* tqchildren of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
*
* Treat the dot entry as if it wasn't there - pretend to move all its
* tqchildren up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
* tqchildren. Subdirectories will be processed before any file tqchildren.
*
* KDotEntryIsSubDir:
*
* Treat the dot entry just like any other subdirectory. Don't iterate
* over its tqchildren, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
* its tqchildren (unless, of course, you create an iterator with the dot
* entry as the parent).
*
* KDotEntryIgnore:
*
* Ignore the dot entry and its tqchildren completely. Useful if tqchildren
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
- * tqchildren.
+ * children.
*
**/
KFileInfoIterator( KFileInfo * parent,
@@ -187,13 +187,13 @@ namespace KDirStat
/**
* Iterator class for tqchildren of a @ref KFileInfo object. This iterator
* returns tqchildren sorted by name: Subdirectories first, then the dot
* entry (if desired - depending on policy), then file tqchildren (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
*
* @short sorted iterator for @ref KFileInfo tqchildren.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
{
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
* Make a 'default order' tqchildren list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
* then the dot entry's tqchildren (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
/**
* Make a sorted tqchildren list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
**/
@@ -265,7 +265,7 @@ namespace KDirStat
// Data members
- KFileInfoList * _tqchildrenList;
+ KFileInfoList * _childrenList;
KFileInfoSortOrder _sortOrder;
bool _ascending;
bool _initComplete;
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
* disregards tqchildren below a minimum size. This can considerably improve
* performance if the number of tqchildren that need to be sorted decreases
* dramatically.
*
* For example, treemaps can only display a limited portion of large
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
* Create the (sorted) tqchildren list. Disregard tqchildren below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/
virtual void makeChildrenList();
@@ -47,8 +47,8 @@ namespace KDirStat
/**
- * Iterator class for tqchildren of a @ref KFileInfo object. For optimum
- * performance, this iterator class does NOT return tqchildren in any
+ * Iterator class for children of a @ref KFileInfo object. For optimum
+ * performance, this iterator class does NOT return children in any
* specific sort order. If you need that, use @ref KFileInfoSortedIterator
* instead.
@@ -66,37 +66,37 @@ namespace KDirStat
* Notice: This does not recurse into subdirectories!
*
- * @short (unsorted) iterator for @ref KFileInfo tqchildren.
+ * @short (unsorted) iterator for @ref KFileInfo children.
**/
class KFileInfoIterator
@@ -66,37 +66,37 @@ namespace KDirStat
/**
* Constructor: Initialize an iterator object to iterate over the
- * tqchildren of 'parent' (unsorted!), depending on 'dotEntryPolicy':
+ * children of 'parent' (unsorted!), depending on 'dotEntryPolicy':
*
* KDotEntryTransparent (default):
@@ -66,37 +66,37 @@ namespace KDirStat
*
* Treat the dot entry as if it wasn't there - pretend to move all its
- * tqchildren up to the real parent. This makes a directory look very
+ * children up to the real parent. This makes a directory look very
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
@@ -66,37 +66,37 @@ namespace KDirStat
* much like the directory on disk, without the dot entry. 'current()'
* or 'operator*()' will never return the dot entry, but all of its
- * tqchildren. Subdirectories will be processed before any file tqchildren.
+ * children. Subdirectories will be processed before any file children.
*
* KDotEntryIsSubDir:
@@ -66,37 +66,37 @@ namespace KDirStat
*
* Treat the dot entry just like any other subdirectory. Don't iterate
- * over its tqchildren, too (unlike KDotEntryTransparent above).
+ * over its children, too (unlike KDotEntryTransparent above).
* 'current()' or 'operator*()' will return the dot entry, but none of
@@ -66,37 +66,37 @@ namespace KDirStat
* 'current()' or 'operator*()' will return the dot entry, but none of
- * its tqchildren (unless, of course, you create an iterator with the dot
+ * its children (unless, of course, you create an iterator with the dot
* entry as the parent).
*
@@ -66,37 +66,37 @@ namespace KDirStat
* KDotEntryIgnore:
*
- * Ignore the dot entry and its tqchildren completely. Useful if tqchildren
+ * Ignore the dot entry and its children completely. Useful if children
* other than subdirectories are not interesting anyway. 'current()'
* or 'operator*()' will never return the dot entry nor any of its
@@ -187,13 +187,13 @@ namespace KDirStat
/**
- * Iterator class for tqchildren of a @ref KFileInfo object. This iterator
- * returns tqchildren sorted by name: Subdirectories first, then the dot
- * entry (if desired - depending on policy), then file tqchildren (if
+ * Iterator class for children of a @ref KFileInfo object. This iterator
+ * returns children sorted by name: Subdirectories first, then the dot
+ * entry (if desired - depending on policy), then file children (if
* desired). Note: If you don't need the sorting feature, you might want to
* use @ref KFileItemIterator instead which has better performance.
@@ -187,13 +187,13 @@ namespace KDirStat
* use @ref KFileItemIterator instead which has better performance.
*
- * @short sorted iterator for @ref KFileInfo tqchildren.
+ * @short sorted iterator for @ref KFileInfo children.
**/
class KFileInfoSortedIterator: public KFileInfoIterator
@@ -248,15 +248,15 @@ namespace KDirStat
void delayedInit();
/**
- * Make a 'default order' tqchildren list:
+ * Make a 'default order' children list:
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
@@ -248,15 +248,15 @@ namespace KDirStat
* First all subdirectories sorted by name,
* then the dot entry (depending on policy),
- * then the dot entry's tqchildren (depending on policy).
+ * then the dot entry's children (depending on policy).
**/
virtual void makeDefaultOrderChildrenList();
@@ -248,15 +248,15 @@ namespace KDirStat
virtual void makeDefaultOrderChildrenList();
/**
- * Make a sorted tqchildren list according to the current sort
+ * Make a sorted children list according to the current sort
* criteria - unless KSortByName is requested, in which case
* makeDefaultOrderChildrenList() above is used.
@@ -276,8 +276,8 @@ namespace KDirStat
/**
* Specialized KFileInfo iterator that sorts by (total) size, yet
- * disregards tqchildren below a minimum size. This can considerably improve
- * performance if the number of tqchildren that need to be sorted decreases
+ * disregards children below a minimum size. This can considerably improve
+ * performance if the number of children that need to be sorted decreases
* dramatically.
*
@@ -307,7 +307,7 @@ namespace KDirStat
protected:
/**
- * Create the (sorted) tqchildren list. Disregard tqchildren below minSize.
+ * Create the (sorted) children list. Disregard children below minSize.
* Reimplemented from KFileInfoSortedIterator.
**/